// importing necessary modules I used for this graph.
import { getData } from './getData';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// declaring constants by reading svg tag from index.html
const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// Start building pie graph
const render = (data,total) => {
  const pieData = pie().value(d=>d.Population)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range([
      "#FFB347",
      "#CF71AF",
      "#A7FC00",
      "#FFFF31",
      "#f58026",
      "#00FFFF",
      "#FFD1DC",
      "#92A1CF",
      "#50C878",
      "#FF9966",
    ]);
  
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.Population));
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Population));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.District);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.Population/1000))+"K");
}

const run = async () => {
  let data = await getData()
  let total = 0
  data.forEach(d=>{
    d.Population = +d.Population;
    total += d.Population
    
  });
  console.log(data)
	render(data,total);
};
run();